Class: Instruction

Inherits:
Object
  • Object
show all
Defined in:
lib/openflowdev/instruction.rb

Overview

Copyright © 2015, BROCADE COMMUNICATIONS SYSTEMS, INC

All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this

list of conditions and the following disclaimer.

  1. Redistributions in binary form must reproduce the above copyright notice,

this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

  1. Neither the name of the copyright holder nor the names of its contributors

may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(instruction_order: nil) ⇒ Instruction

Returns a new instance of Instruction.

Raises:

  • (ArgumentError)


35
36
37
38
39
# File 'lib/openflowdev/instruction.rb', line 35

def initialize(instruction_order: nil)
  raise ArgumentError, "Instruction Order (instruction_order) required" unless instruction_order
  @order = instruction_order
  @actions = []
end

Instance Attribute Details

#actionsObject (readonly)

Returns the value of attribute actions.



33
34
35
# File 'lib/openflowdev/instruction.rb', line 33

def actions
  @actions
end

#orderObject

Returns the value of attribute order.



32
33
34
# File 'lib/openflowdev/instruction.rb', line 32

def order
  @order
end

Instance Method Details

#add_apply_action(action) ⇒ Object

Raises:

  • (ArgumentError)


41
42
43
44
# File 'lib/openflowdev/instruction.rb', line 41

def add_apply_action(action)
  raise ArgumentError, "Action must be a subclass of 'Action'" unless action.is_a?(Action)
  @actions << action
end

#to_hashObject



46
47
48
49
50
51
52
# File 'lib/openflowdev/instruction.rb', line 46

def to_hash
  actions_hash = []
  @actions.each do |action|
    actions_hash << action.to_hash
  end
  {:order => @order, 'apply-actions' => {:action => actions_hash}}
end